@@ -32,6 +32,7 @@ aswsindexeod = os.path.join(data_path,r'ASWSIndexEOD')
 aindex_eod_price = os.path.join(data_path,r'AIndexEODPrices')
 aindex_idueodcitics = os.path.join(data_path,r'AIndexIndustriesEODCITICS')
 aindex_freeweight = os.path.join(data_path,r'AIndexFreeWeight')
+cmf_indexeod = os.path.join(data_path,r"CMFIndexEOD")
 
 shszstockholding = os.path.join(data_path,r"SHSZstockhoding")
 #%%
@@ -104,6 +105,10 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     @print_func_time
     def get_daily_aswsindexeod(self,instruments,fields,start_date,end_date):
         return self.get_daily_data(aswsindexeod,instruments,fields,start_date,end_date)
+    
+    @print_func_time
+    def get_daily_cmfidxeod(self,instruments,fields,start_date,end_date):
+        return self.get_daily_data(cmf_indexeod,instruments,fields,start_date,end_date)
 
     @print_func_time
     def get_daily_dly_specret(self,instruments,fields,start_date,end_date):
