@@ -54,6 +54,8 @@ def read_mergeh5(path,ori_instruments,fields,start_index,end_index,tidx = 'trade
         cidx =  h5['data'].shape[0]  
 
     dset = wrap_dset(path,'data')
+    if isinstance(ori_instruments,None.__class__):
+        ori_instruments = instlist
     labels,infoloc = get_availables(ori_instruments,instlist)
     if len(infoloc) == 0:
         return pd.DataFrame()
